﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;

using SPCSharePointSearch2.SearchService;

namespace SPCSharePointSearch2
{
    public partial class MainPage : UserControl
    {
        public MainPage()
        {
            InitializeComponent();
        }

        private void SearchButton_Click(object sender, RoutedEventArgs e)
        {
            StringBuilder searchQuery = new StringBuilder();

            if (!string.IsNullOrEmpty(SearchTextBox.Text))
                searchQuery.AppendFormat("{0} ", SearchTextBox.Text);

            if (FileSizeOperatorComboBox.SelectedItem != null)
                searchQuery.AppendFormat("Size{0}\"{1}\" ",
                    ((ComboBoxItem)FileSizeOperatorComboBox.SelectedItem).Content.ToString(),
                    FileSizeTextBox.Text);

            if (ModifiedDateOperatorComboBox.SelectedItem != null)
                searchQuery.AppendFormat("Write{0}\"{1}\" ",
                    ((ComboBoxItem)ModifiedDateOperatorComboBox.SelectedItem).Content.ToString(),
                    ModifiedDatePicker.SelectedDate.ToString());

            if (!string.IsNullOrEmpty(AuthorTextBox.Text))
                searchQuery.AppendFormat("Author:\"{0}\" ", AuthorTextBox.Text);

            if (DocumentsOnlyCheckBox.IsChecked.Value)
                searchQuery.Append("IsDocument:1 ");

            // pass the search query to the method to actually call the search service
            QuerySearchService(searchQuery.ToString());
        }

        private void QuerySearchService(string searchQuery)
        {
            QueryServiceSoapClient queryService = new QueryServiceSoapClient();
            queryService.QueryExCompleted += new EventHandler<QueryExCompletedEventArgs>(QueryService_QueryExCompleted);

            QueryTextBox.Text = searchQuery;
            StringBuilder queryXml = new StringBuilder();

            queryXml.Append("<QueryPacket xmlns=\"urn:Microsoft.Search.Query\" Revision=\"1000\">");
            queryXml.Append("<Query domain=\"QDomain\">");
            queryXml.Append("<SupportedFormats>");
            queryXml.Append("<Format>");
            queryXml.Append("urn:Microsoft.Search.Response.Document.Document");
            queryXml.Append("</Format>");
            queryXml.Append("</SupportedFormats>");
            queryXml.Append("<Range>");
            queryXml.Append("<Count>50</Count>");
            queryXml.Append("</Range>");
            queryXml.Append("<Context>");
            queryXml.Append("<QueryText language=\"en-US\" type=\"STRING\">");
            queryXml.Append(searchQuery);
            queryXml.Append("</QueryText>");
            queryXml.Append("</Context>");
            queryXml.Append("</Query>");
            queryXml.Append("</QueryPacket>");

            BusyIndicator.IsBusy = true;
            queryService.QueryExAsync(queryXml.ToString());
        }


        void QueryService_QueryExCompleted(object sender, QueryExCompletedEventArgs e)
        {
            try
            {
                ResultsTextBox.Text = e.Result.Nodes[1].ToString();

                var results = from result in
                                  e.Result.Nodes[1].Descendants("RelevantResults")
                              select new SearchResult
                              {
                                  Title = (result.Elements("Title").Any())
                                    ? result.Element("Title").Value : string.Empty,
                                  Path = (result.Elements("Path").Any()) 
                                    ? result.Element("Path").Value : string.Empty,
                                  Author = (result.Elements("Author").Any()) 
                                    ? result.Element("Author").Value : string.Empty,
                                  Size = (result.Elements("Size").Any()) 
                                    ? result.Element("Size").Value : string.Empty,
                                  Write = (result.Elements("Write").Any()) 
                                    ? DateTime.Parse(result.Element("Write").Value) : DateTime.MinValue,
                                  SiteName = (result.Elements("SiteName").Any()) 
                                    ? result.Element("SiteName").Value : string.Empty,
                                  HitHighlightedSummary = (result.Elements("HitHighlightedSummary").Any()) 
                                    ? result.Element("HitHighlightedSummary").Value : string.Empty,
                                  ContentClass = (result.Elements("ContentClass").Any()) 
                                    ? result.Element("ContentClass").Value : string.Empty,
                                  IsDocument = (result.Elements("IsDocument").Any()) 
                                    ? bool.Parse(result.Element("IsDocument").Value) : false
                              };

                ResultsRadGridView.ItemsSource = results;
            }
            catch (Exception exception)
            {
                ResultsTextBox.Text = exception.ToString();
            }
            finally
            {
                BusyIndicator.IsBusy = false;
            }
        }

        private void QueryButton_Click(object sender, RoutedEventArgs e)
        {
            QuerySearchService(QueryTextBox.Text);
        }

        private void ResetButton_Click(object sender, RoutedEventArgs e)
        {
            SearchTextBox.Text = string.Empty;
            FileSizeTextBox.Text = string.Empty;
            FileSizeOperatorComboBox.SelectedIndex = -1;
            ModifiedDateOperatorComboBox.SelectedIndex = -1;
            ModifiedDatePicker.SelectedDate = null;
            AuthorTextBox.Text = string.Empty;
            DocumentsOnlyCheckBox.IsChecked = false;
            QueryTextBox.Text = string.Empty;
        }


    }
}
